// PURPOSE: Visual client for Arduino Sketch: TCRT5000L
// DATE:    2012 11 28
// AUTHOR:  C. D'Arcy
import processing.serial.*;
Serial commPort;
PFont font12;
PFont font16;
PFont font24;
PFont font32;
// define the entre width of the interface based on the column widths
int numColumns = 9;
int colHeight = 255;
int colWidth = 48;
int leftMargin = colWidth*3;
int rightMargin = leftMargin;
int topMargin = 50;
int bottomMargin = 40;
int width = leftMargin+numColumns*colWidth+rightMargin;
int height = topMargin+colHeight+bottomMargin;
int leftMotorSpeed;
int rightMotorSpeed;
int sum;
int weightedAverage;
int sensor = 0;
int numSensors = 5;


int yDist;
int dwidth = width - rightMargin - leftMargin;
int dheight = height - topMargin - bottomMargin;
int tlc = leftMargin;
int tlr = topMargin;
int brc = width - rightMargin;
int brr = height - bottomMargin;
color red = color(255, 0, 0);
color green = color(0, 255, 0);
color blue = color(0, 0, 255);
color mag = color(255, 0, 255);
color cyan = color(0, 255, 255);
color yellow = color(255, 255, 0);
color [] palette = {
  color(255, 0, 0), green, blue, mag, cyan, yellow
};
int reading;
int[] readings = new int[numSensors];

void setup() {
  font12 = loadFont("Verdana-12.vlw"); 
  font24 = loadFont("Verdana-24.vlw"); 
  font32 = loadFont("Verdana-32.vlw");
  size(width, height);
  display();
  String port = Serial.list()[0];
  commPort = new Serial(this, port, 9600);
  commPort.clear();
}

void draw() {
  if (commPort.available() > 0) { 
    reading = commPort.read();
    readings[sensor] = reading;
    // update sensor number with loop back to 0
    sensor = (sensor+1)%numSensors; 
    // update display only after ALL numSensors have have been assigned a new reading
    if (sensor==0) {
      display();
      saveFrame("TCRT5000L-####.png");
    }
  }
} 
void display() {
  fill(200);
  rect(0, 0, width, height);
  fill(0);
  textAlign(CENTER);
  textFont(font24);
  text("2012-2013 RSGC ACES: TCRT5000 5-Sensor Simulation", (tlc+brc)/2, 32);
  stroke(0);
  fill(180);
  rect(tlc, tlr, dwidth, dheight);
  // plot 'em
  textFont(font12);
  textAlign(CENTER);
  fill(0);
  text("LEFT", leftMargin/2, height-10); 
  text("RIGHT", width-rightMargin/2, height-10); 
  sum = 0;
  for (int i=0; i<numSensors; i++) {
    sum += (i-2)*readings[i];
    text("Sensor"+i, leftMargin+colWidth*(4*i+1)/2, height-10); 
    fill(0);
    rect(tlc+colWidth*2*i, brr-readings[i], colWidth, readings[i]);
  }
  weightedAverage=sum/numSensors;
  fill(green);
  leftMotorSpeed = 255;
  rightMotorSpeed = 255;

  if (abs(weightedAverage)>30)
    if (weightedAverage>0) {
    rightMotorSpeed = 0;
    } 
  else {
    leftMotorSpeed = 0;
  }
  rect(colWidth, brr-leftMotorSpeed, colWidth, leftMotorSpeed);
  rect(brc+colWidth, brr-rightMotorSpeed, colWidth, rightMotorSpeed);

  println(weightedAverage);
}

